@@ -1,6 +1,5 @@
 package Kelp::Module::Whelk;
-$Kelp::Module::Whelk::VERSION = '0.99_01'; # TRIAL
-$Kelp::Module::Whelk::VERSION = '0.9901';
+$Kelp::Module::Whelk::VERSION = '0.01';
 use Kelp::Base 'Kelp::Module';
 use Kelp::Util;
 use Carp;
@@ -132,9 +131,15 @@ sub _install_openapi
 		path => $config
 	} unless ref $config eq 'HASH';
 
+	croak "Wrong path for openapi"
+		unless $config->{path} =~ m{^/};
+
 	my $openapi_class = $self->_load_package($config->{class} // 'Whelk::OpenAPI');
 	$self->openapi_generator($openapi_class->new);
 
+	my $formatter_class = $self->_load_package($config->{formatter} // $args->{formatter}, 'Whelk::Formatter');
+	my $formatter = $formatter_class->new(app => $self->app);
+
 	$self->openapi_generator->parse(
 		app => $app,
 		info => $config->{info},
@@ -143,99 +148,16 @@ sub _install_openapi
 		schemas => Whelk::Schema->all_schemas,
 	);
 
-	if (defined $config->{path}) {
-		croak "Wrong path for openapi"
-			unless $config->{path} =~ m{^/};
+	$app->add_route(
+		[GET => $config->{path}] => sub {
+			my ($app) = @_;
 
-		my $formatter_class = $self->_load_package($config->{formatter} // $args->{formatter}, 'Whelk::Formatter');
-		my $formatter = $formatter_class->new(app => $self->app);
+			my $generated = $self->openapi_generator->generate();
 
-		$app->add_route(
-			[GET => $config->{path}] => sub {
-				my ($app) = @_;
-
-				my $generated = $self->openapi_generator->generate();
-
-				return $formatter->format_response($app, $generated, 'openapi');
-			}
-		);
-	}
+			return $formatter->format_response($app, $generated, 'openapi');
+		}
+	);
 }
 
 1;
 
-__END__
-
-=pod
-
-=head1 NAME
-
-Kelp::Module::Whelk - Whelk as a Kelp module
-
-=head1 SYNOPSIS
-
-	# in Kelp configuration
-	{
-		modules => [qw(Whelk)],
-		modules_init => {
-			Whelk => {
-				resources => {
-					MyResource => '/',
-				},
-
-				# rest of the normal Whelk configuration
-				...
-			},
-		},
-	}
-
-=head1 DESCRIPTION
-
-Whelk module is a Kelp module which implements Whelk. If is used by default by
-the standalone L<Whelk> module and can be used explicitly in a Kelp application
-to add Whelk API to it.
-
-See L<Whelk::Manual::Kelp> for details on how to use Whelk in existing Kelp
-applications. There is no need to interact with this module in standalone
-applications.
-
-=head1 METHODS ADDED TO KELP
-
-This module just adds a single method to the Kelp application, C<whelk>, which
-returns instance of this module.
-
-=head1 ATTRIBUTES
-
-These attributes are generated by the module as a result of looking at the
-config. Most of those will not be available before L</finalize> is called.
-
-=head2 config
-
-Whelk-specific configuration as the module sees it.
-
-=head2 inhale_response
-
-Whether to inhale response before exhaling it.
-
-=head2 openapi_generator
-
-Instance of L<Whelk::OpenAPI> or other class used to generate the OpenAPI document.
-
-=head2 resources
-
-Metadata for Whelk resources in form of a hashref.
-
-=head2 endpoints
-
-An array reference of all endpoint instances created by C<add_endpoint> calls.
-
-=head1 METHODS
-
-=head2 finalize
-
-	$self->whelk->finalize;
-
-Finalizes the API by calling all resources, installing their endpoints and
-installing the OpenAPI endpoint. Must be called explicitly in application's
-C<build> method.
-
