@@ -1,6 +1,5 @@
 package Whelk;
-$Whelk::VERSION = '0.99_01'; # TRIAL
-$Whelk::VERSION = '0.9901';
+$Whelk::VERSION = '0.01';
 use Kelp::Base 'Kelp';
 
 attr 'config_module' => '+Whelk::Config';
@@ -31,13 +30,6 @@ Whelk - A friendly API framework based on Kelp
 
 =head1 DESCRIPTION
 
-=begin html
-
-<p style="text-align: center"><img width="80%" src="https://raw.githubusercontent.com/Kelp-framework/Art/master/whelk/logo_wide.png" alt="logo"></p>
-<p style="text-align: center"><b>A friendly web API framework</b></p>
-
-=end html
-
 Whelk is an API framework which helps you create correct, fast,
 self-documenting APIs. It's easy to learn, fun to work with and extremely
 customizable. It can be run either standalone as a L<Plack> application, or
@@ -46,9 +38,8 @@ inside a L<Kelp> application as a module.
 Whelk is integrated with OpenAPI/Swagger and automatically generates a document
 according to spec v3 rules. All the data for the document is taken directly
 from your endpoint validation rules, which ensures only minimal effort is
-needed to generate a documentation for your project. The resulting
-documentation can be beautifully visualized using OpenAPI tools like Swagger
-UI.
+needed to generate a documentation for your project, which can be beautifully
+visualized using OpenAPI tools like Swagger UI.
 
 To get started, take a look at L<Whelk::Manual>.
 
