@@ -1,6 +1,5 @@
 package Whelk::Config;
-$Whelk::Config::VERSION = '0.99_01'; # TRIAL
-$Whelk::Config::VERSION = '0.9901';
+$Whelk::Config::VERSION = '0.01';
 use Kelp::Base 'Kelp::Module::Config';
 
 attr data => sub {
@@ -26,8 +25,6 @@ attr data => sub {
 				},
 			},
 
-			persistent_controllers => 1,
-
 			encoders => {
 				json => {
 					openapi => {
