@@ -1,23 +1,20 @@
 package Whelk::Endpoint;
-$Whelk::Endpoint::VERSION = '0.99_01'; # TRIAL
-$Whelk::Endpoint::VERSION = '0.9901';
-use Whelk::StrictBase;
+$Whelk::Endpoint::VERSION = '0.01';
+use Kelp::Base;
 use Carp;
 use Whelk::Schema;
-use Whelk::Endpoint::Parameters;
 
-attr '?-id' => sub { $_[0]->route->has_name ? $_[0]->route->name : undef };
-attr '?-summary' => undef;
-attr '?-description' => undef;
+attr -id => sub { $_[0]->route->has_name ? $_[0]->route->name : undef };
+attr -summary => undef;
+attr -description => undef;
 attr -resource => sub { croak 'resource is required in endpoint' };
 attr -route => sub { croak 'route is required in endpoint' };
+attr -code => sub { croak 'code is required in endpoint' };
+attr -path => \&_build_path;
 attr -formatter => sub { croak 'formatter is required in endpoint' };
-attr -wrapper => sub { croak 'wrapper is required in endpoint' };
-attr code => undef;
-attr path => undef;
-attr '?request' => undef;
-attr '?response' => undef;
-attr '?parameters' => undef;
+attr -request_schema => undef;
+attr -response_schema => sub { croak 'response_schema is required in endpoint' };
+attr -parameters => sub { croak 'parameters are required in endpoint' };
 
 # to be built in wrapers
 attr -response_schemas => sub { {} };
@@ -27,15 +24,7 @@ sub new
 	my $class = shift;
 	my $self = $class->SUPER::new(@_);
 
-	# build request and response schemas
-	$self->request(Whelk::Schema->build_if_defined($self->request));
-	$self->response(Whelk::Schema->build_if_defined($self->response));
-
-	# initial build of the parameters
-	$self->parameters(Whelk::Endpoint::Parameters->new(%{$self->parameters // {}}));
-
-	# build path
-	$self->path($self->_build_path);
+	$self->path;    # builds path
 
 	# build schemas to get any errors reported early
 	$self->parameters->path_schema;
@@ -43,10 +32,6 @@ sub new
 	$self->parameters->header_schema;
 	$self->parameters->cookie_schema;
 
-	# wrap the endpoint sub
-	$self->code($self->route->dest->[1]);
-	$self->route->dest->[1] = $self->wrapper->wrap($self);
-
 	return $self;
 }
 
@@ -77,5 +62,13 @@ sub _build_path
 	return $path;
 }
 
+sub wrap
+{
+	my ($self, $controller) = @_;
+
+	$self->route->dest->[0] //= ref $controller;    # make sure plain subs work
+	$self->route->dest->[1] = $controller->_whelk_config('wrapper')->wrap($self);
+}
+
 1;
 
