@@ -1,15 +1,14 @@
 package Whelk::Endpoint::Parameters;
-$Whelk::Endpoint::Parameters::VERSION = '0.99_01'; # TRIAL
-$Whelk::Endpoint::Parameters::VERSION = '0.9901';
-use Whelk::StrictBase;
+$Whelk::Endpoint::Parameters::VERSION = '0.01';
+use Kelp::Base;
 
 use Carp;
 use Whelk::Schema;
 
-attr '?-path' => sub { {} };
-attr '?-query' => sub { {} };
-attr '?-header' => sub { {} };
-attr '?-cookie' => sub { {} };
+attr -path => sub { {} };
+attr -query => sub { {} };
+attr -header => sub { {} };
+attr -cookie => sub { {} };
 
 attr -path_schema => sub { $_[0]->build_schema($_[0]->path, required => 1) };
 attr -query_schema => sub { $_[0]->build_schema($_[0]->query, array => 1) };
