@@ -1,11 +1,8 @@
 package Whelk::OpenAPI;
-$Whelk::OpenAPI::VERSION = '0.99_01'; # TRIAL
-$Whelk::OpenAPI::VERSION = '0.9901';
+$Whelk::OpenAPI::VERSION = '0.01';
 use Kelp::Base;
 use List::Util qw(uniq);
 
-attr openapi_version => '3.0.3';
-
 attr info => sub { {} };
 attr extra => sub { {} };
 attr tags => sub { [] };
@@ -13,7 +10,7 @@ attr paths => sub { {} };
 attr schemas => sub { {} };
 attr servers => sub { [] };
 
-sub default_response_description
+sub default_res_desc
 {
 	my ($self, $code) = @_;
 
@@ -32,7 +29,7 @@ sub default_response_description
 	return 'Response.';
 }
 
-sub build_path
+sub _build_path
 {
 	my ($self, $endpoint) = @_;
 	my %requests;
@@ -48,12 +45,12 @@ sub build_path
 
 			# special case for no content response
 			$responses{204} = {
-				description => $schema->description // $self->default_response_description(204),
+				description => $schema->description // $self->default_res_desc(204),
 			};
 		}
 		else {
 			$responses{$code} = {
-				description => $schema->description // $self->default_response_description($code),
+				description => $schema->description // $self->default_res_desc($code),
 				content => {
 					$endpoint->formatter->full_response_format => {
 						schema => $schema->openapi_schema($self),
@@ -64,7 +61,7 @@ sub build_path
 	}
 
 	# build requests
-	if (my $schema = $endpoint->request) {
+	if (my $schema = $endpoint->request_schema) {
 		foreach my $format (values %{$endpoint->formatter->supported_formats}) {
 			$requests{content}{$format}{schema} = $schema->openapi_schema($self);
 		}
@@ -90,14 +87,26 @@ sub build_path
 	};
 }
 
-sub build_paths
+sub parse
 {
-	my ($self, $endpoints) = @_;
+	my ($self, %data) = @_;
+
+	$self->info($data{info} // {});
+	$self->extra($data{extra} // {});
+
+	$self->servers(
+		[
+			{
+				description => 'API for ' . $data{app}->name,
+				url => $data{app}->config('app_url'),
+			},
+		]
+	);
 
 	my %paths;
 	my @tags;
-	foreach my $endpoint (@{$endpoints // []}) {
-		$paths{$endpoint->path}{lc $endpoint->route->method} = $self->build_path($endpoint);
+	foreach my $endpoint (@{$data{endpoints} // []}) {
+		$paths{$endpoint->path}{lc $endpoint->route->method} = $self->_build_path($endpoint);
 
 		push @tags, $endpoint->resource;
 	}
@@ -110,47 +119,15 @@ sub build_paths
 			($_->config->{description} ? (description => $_->config->{description}) : ()),
 		}
 	} uniq @tags;
-
 	$self->tags(\@tags);
-}
-
-sub build_servers
-{
-	my ($self, $app) = @_;
-
-	$self->servers(
-		[
-			{
-				description => 'API for ' . $app->name,
-				url => $app->config('app_url'),
-			},
-		]
-	);
-}
-
-sub build_schemas
-{
-	my ($self, $schemas) = @_;
 
 	my %schemas = map {
 		$_->name => $_->openapi_schema($self, full => 1)
-	} @{$schemas // []};
+	} @{$data{schemas} // []};
 
 	$self->schemas(\%schemas);
 }
 
-sub parse
-{
-	my ($self, %data) = @_;
-
-	$self->info($data{info} // {});
-	$self->extra($data{extra} // {});
-
-	$self->build_paths($data{endpoints});
-	$self->build_servers($data{app});
-	$self->build_schemas($data{schemas});
-}
-
 sub location_for_schema
 {
 	my ($self, $name) = @_;
@@ -167,7 +144,7 @@ sub generate
 		# extra at the start, to make sure it's not overshadowing keys
 		%{$self->extra},
 
-		openapi => $self->openapi_version,
+		openapi => '3.0.3',
 		info => $self->info,
 		servers => $self->servers,
 		tags => $self->tags,
@@ -182,73 +159,3 @@ sub generate
 
 1;
 
-__END__
-
-=pod
-
-=head1 NAME
-
-Whelk::OpenAPI - Whelk's default OpenAPI generator class
-
-=head1 SYNOPSIS
-
-	# whelk_config.pl
-	###################
-	{
-		openapi => {
-			path => '/openapi',
-			class => 'MyOpenAPI',
-		}
-	}
-
-	# MyOpenAPI.pm
-	################
-	package MyOpenAPI;
-
-	use Kelp::Base 'Whelk::OpenAPI';
-
-	sub parse {
-		my ($self, %data) = @_;
-
-		# do the parsing differently
-		...
-	}
-
-	1;
-
-=head1 DESCRIPTION
-
-This class generates an OpenAPI document based on the API definition gathered
-by Whelk. It requires pretty specific setup and should probably not be
-manipulated by hand. It can be subclassed to change how the document looks.
-
-This documentation page describes just the methods which are called from
-outside of the class. The rest of methods and all attributes are just
-implementation details.
-
-=head1 METHODS
-
-=head2 parse
-
-	$openapi->parse(%data);
-
-It's called at build time, after Whelk is finalized. It gets passed a hash
-C<%data> with a couple of keys containing full data Whelk gathered. It should
-build most of the parts of the OpenAPI document, so that it will not be
-terribly slow to generate the document at runtime.
-
-=head2 location_for_schema
-
-	my $location = $openapi->location_for_schema($schema_name);
-
-This helper should just return a string which will be put into C<'$ref'> keys
-of the OpenAPI document to reference named schemas.
-
-=head2 generate
-
-	my $openapi_document_data = $openapi->generate;
-
-This method should take all the data prepared by L</parse> and return a hash
-reference with all the data of the OpenAPI document. This data will be then
-serialized using formatter declared in C<openapi> configuration.
-
