@@ -1,6 +1,5 @@
 package Whelk::Schema;
-$Whelk::Schema::VERSION = '0.99_01'; # TRIAL
-$Whelk::Schema::VERSION = '0.9901';
+$Whelk::Schema::VERSION = '0.01';
 use Kelp::Base -strict;
 use Whelk::Schema::Definition;
 use Carp;
@@ -170,18 +169,14 @@ Each new schema must have a C<type> defined. All types share these common config
 
 =over
 
-=item * required
+=item required
 
 Boolean - whether the value is required to be present. C<true> by default.
 
-=item * description
+=item description
 
 String - an optional description used for the schema in the OpenAPI document.
 
-=item * rules
-
-An array reference of hashes. See L</Extra rules>.
-
 =back
 
 =head3 null
@@ -207,11 +202,11 @@ Extra configuration fields:
 
 =over
 
-=item * default
+=item default
 
 A default value to be used when there is no value. Also assumes C<< required => !!0 >>.
 
-=item * example
+=item example
 
 An optional example used for the schema in the OpenAPI document.
 
@@ -244,13 +239,13 @@ Extra configuration fields:
 
 =over
 
-=item * items
+=item items
 
 An optional type to use for each of the array elements. This is a nested
 schema, and all ways to define a schema discussed in L</Defining a schema> will
 work.
 
-=item * lax
+=item lax
 
 This is a special boolean flag used to accept array C<parameters> of type
 C<query> and C<header>. If present and true, the type will also accept a
@@ -269,13 +264,13 @@ Extra configuration fields:
 
 =over
 
-=item * properties
+=item properties
 
 An optional dictionary to use for the keys in the object. If it's not
 specified, the object can contain anything. This is a nested schema, and all
 ways to define a schema discussed in L</Defining a schema> will work.
 
-=item * strict
+=item strict
 
 This is a special boolean flag used to make any schema which does contain extra
 keys as those specified in C<properties> incorrect. By default, the hash can
@@ -285,69 +280,6 @@ required.
 
 =back
 
-=head2 Extra rules
-
-Whelk does not define a full JSONSchema spec with all its rules. To allow
-configuration, you can specify extra rules when needed which will be used
-during validation and may optionally add some keys to the OpenAPI spec of that
-field. While all field types allow defining extra rules, it makes little sense
-to use them for types C<boolean>, C<null> and C<empty> - rules will do nothing
-for them.
-
-An example of adding some rules is showcased below:
-
-	{
-		type => 'integer',
-		rules => [
-			{
-				openapi => {
-					minimum => '5',
-				},
-				hint => '(>=5)',
-				code => sub {
-					my $value = shift;
-
-					return $value >= 5;
-				},
-			},
-		],
-	}
-
-As shown, a C<rules> array reference may be defined, containing hash
-references. Each rule (represented by a hash reference) must contain C<hint> (a
-very short error message notifying the end user what's wrong), C<code> (a sub
-reference, which will be passed the value and must return C<true> if the value
-is valid) and optionally C<openapi> (a hash reference, containing keys which
-will be added to OpenAPI document).
-
-There may be multiple rules in each field, and each rule can contain multiple
-C<openapi> keys (but only a single C<code> and C<hint>). This system is very
-bare-bones and a bit verbose, but it makes it very easy to write your own
-library of validations, implementing the parts of JSONSchema you need (or even
-the full schema - please publish to CPAN if you do!). Just write a function
-which will return a given hash reference and it becomes quite powerful:
-
-	sub greater_or_equal
-	{
-		my ($arg) = @_;
-
-		return {
-			openapi => {
-				minimum => $arg,
-			},
-			hint => "(>=$arg)",
-			code => sub { shift() >= $arg },
-		};
-	}
-
-	... then
-	{
-		type => 'integer',
-		rules => [
-			greater_or_equal(5),
-		],
-	}
-
 =head1 METHODS
 
 This is a list of factory methods implemented by C<Whelk::Schema>.
