@@ -1,17 +1,15 @@
 package Whelk::Schema::Definition::Array;
-$Whelk::Schema::Definition::Array::VERSION = '0.99_01'; # TRIAL
-$Whelk::Schema::Definition::Array::VERSION = '0.9901';
-use Whelk::StrictBase 'Whelk::Schema::Definition';
+$Whelk::Schema::Definition::Array::VERSION = '0.01';
+use Kelp::Base 'Whelk::Schema::Definition';
 
-attr '?items' => undef;
-attr '?lax' => !!0;
+attr items => undef;
+attr lax => !!0;
 
 sub openapi_dump
 {
 	my ($self, $openapi_obj, %hints) = @_;
 
 	my $res = {
-		%{$self->_openapi_dump_extra_rules},
 		type => 'array',
 		($self->items ? (items => $self->items->openapi_schema($openapi_obj)) : ()),
 	};
@@ -37,23 +35,23 @@ sub inhale
 
 	if (ref $value eq 'ARRAY') {
 		my $type = $self->items;
-		if ($type) {
-			foreach my $index (keys @$value) {
-				my $inhaled = $type->inhale($value->[$index]);
-				return "array[$index]->$inhaled" if defined $inhaled;
-			}
+		return undef unless $type;
+
+		foreach my $index (keys @$value) {
+			my $inhaled = $type->inhale($value->[$index]);
+			return "array[$index]->$inhaled" if defined $inhaled;
 		}
 
-		return $self->_inhale_extra_rules($value);
+		return undef;
 	}
 	elsif ($self->lax) {
 		my $type = $self->items;
-		if ($type) {
-			my $inhaled = $type->inhale($value);
-			return "array[0]->$inhaled" if defined $inhaled;
-		}
+		return undef unless $type;
 
-		return $self->_inhale_extra_rules($value);
+		my $inhaled = $type->inhale($value);
+		return "array[0]->$inhaled" if defined $inhaled;
+
+		return undef;
 	}
 
 	return 'array';
