@@ -1,7 +1,6 @@
 package Whelk::Schema::Definition::Boolean;
-$Whelk::Schema::Definition::Boolean::VERSION = '0.99_01'; # TRIAL
-$Whelk::Schema::Definition::Boolean::VERSION = '0.9901';
-use Whelk::StrictBase 'Whelk::Schema::Definition::_Scalar';
+$Whelk::Schema::Definition::Boolean::VERSION = '0.01';
+use Kelp::Base 'Whelk::Schema::Definition::_Scalar';
 use JSON::PP;
 use List::Util qw(none);
 
@@ -18,11 +17,11 @@ sub openapi_dump
 	}
 
 	if ($self->has_default) {
-		$res->{default} = $self->inhale_exhale;
+		$res->{default} = $self->exhale;
 	}
 
 	if (defined $self->example) {
-		$res->{example} = $self->inhale_exhale($self->example);
+		$res->{example} = $self->example;
 	}
 
 	return $res;
