@@ -1,7 +1,6 @@
 package Whelk::Schema::Definition::Empty;
-$Whelk::Schema::Definition::Empty::VERSION = '0.99_01'; # TRIAL
-$Whelk::Schema::Definition::Empty::VERSION = '0.9901';
-use Whelk::StrictBase 'Whelk::Schema::Definition';
+$Whelk::Schema::Definition::Empty::VERSION = '0.01';
+use Kelp::Base 'Whelk::Schema::Definition';
 
 sub inhale
 {
