@@ -1,7 +1,6 @@
 package Whelk::Schema::Definition::Null;
-$Whelk::Schema::Definition::Null::VERSION = '0.99_01'; # TRIAL
-$Whelk::Schema::Definition::Null::VERSION = '0.9901';
-use Whelk::StrictBase 'Whelk::Schema::Definition';
+$Whelk::Schema::Definition::Null::VERSION = '0.01';
+use Kelp::Base 'Whelk::Schema::Definition';
 
 sub openapi_dump
 {
