@@ -1,7 +1,6 @@
 package Whelk::Schema::Definition::Number;
-$Whelk::Schema::Definition::Number::VERSION = '0.99_01'; # TRIAL
-$Whelk::Schema::Definition::Number::VERSION = '0.9901';
-use Whelk::StrictBase 'Whelk::Schema::Definition::_Scalar';
+$Whelk::Schema::Definition::Number::VERSION = '0.01';
+use Kelp::Base 'Whelk::Schema::Definition::_Scalar';
 use Scalar::Util qw(looks_like_number);
 
 sub openapi_dump
@@ -9,7 +8,6 @@ sub openapi_dump
 	my ($self, $openapi_obj, %hints) = @_;
 
 	my $res = {
-		%{$self->_openapi_dump_extra_rules},
 		type => 'number',
 	};
 
@@ -18,11 +16,11 @@ sub openapi_dump
 	}
 
 	if ($self->has_default) {
-		$res->{default} = $self->inhale_exhale;
+		$res->{default} = $self->exhale;
 	}
 
 	if (defined $self->example) {
-		$res->{example} = $self->inhale_exhale($self->example);
+		$res->{example} = $self->example;
 	}
 
 	return $res;
@@ -35,7 +33,7 @@ sub _inhale
 	my $inhaled = $self->SUPER::_inhale($value);
 	return $inhaled if defined $inhaled;
 	return 'number' unless looks_like_number($value);
-	return $self->_inhale_extra_rules($value);
+	return undef;
 }
 
 sub _exhale
