@@ -1,10 +1,9 @@
 package Whelk::Schema::Definition::Object;
-$Whelk::Schema::Definition::Object::VERSION = '0.99_01'; # TRIAL
-$Whelk::Schema::Definition::Object::VERSION = '0.9901';
-use Whelk::StrictBase 'Whelk::Schema::Definition';
+$Whelk::Schema::Definition::Object::VERSION = '0.01';
+use Kelp::Base 'Whelk::Schema::Definition';
 
-attr '?properties' => undef;
-attr '?strict' => !!0;
+attr properties => undef;
+attr strict => !!0;
 
 sub openapi_dump
 {
@@ -15,7 +14,6 @@ sub openapi_dump
 	}
 
 	my $res = {
-		%{$self->_openapi_dump_extra_rules},
 		type => 'object',
 	};
 
@@ -81,28 +79,28 @@ sub inhale
 
 	if (ref $value eq 'HASH') {
 		my $properties = $self->properties;
-		if ($properties) {
-			foreach my $key (keys %$properties) {
-				if (!exists $value->{$key}) {
-					return "object[$key]->required"
-						if $properties->{$key}->required;
+		return undef unless $properties;
 
-					next;
-				}
+		foreach my $key (keys %$properties) {
+			if (!exists $value->{$key}) {
+				return "object[$key]->required"
+					if $properties->{$key}->required;
 
-				my $inhaled = $properties->{$key}->inhale($value->{$key});
-				return "object[$key]->$inhaled" if defined $inhaled;
+				next;
 			}
 
-			if ($self->strict && keys %$value > keys %$properties) {
-				foreach my $key (keys %$value) {
-					next if exists $properties->{$key};
-					return "object[$key]->redundant";
-				}
+			my $inhaled = $properties->{$key}->inhale($value->{$key});
+			return "object[$key]->$inhaled" if defined $inhaled;
+		}
+
+		if ($self->strict && keys %$value > keys %$properties) {
+			foreach my $key (keys %$value) {
+				next if exists $properties->{$key};
+				return "object[$key]->redundant";
 			}
 		}
 
-		return $self->_inhale_extra_rules($value);
+		return undef;
 	}
 
 	return 'object';
