@@ -1,14 +1,12 @@
 package Whelk::Schema::Definition::String;
-$Whelk::Schema::Definition::String::VERSION = '0.99_01'; # TRIAL
-$Whelk::Schema::Definition::String::VERSION = '0.9901';
-use Whelk::StrictBase 'Whelk::Schema::Definition::_Scalar';
+$Whelk::Schema::Definition::String::VERSION = '0.01';
+use Kelp::Base 'Whelk::Schema::Definition::_Scalar';
 
 sub openapi_dump
 {
 	my ($self, $openapi_obj, %hints) = @_;
 
 	my $res = {
-		%{$self->_openapi_dump_extra_rules},
 		type => 'string',
 	};
 
@@ -17,11 +15,11 @@ sub openapi_dump
 	}
 
 	if ($self->has_default) {
-		$res->{default} = $self->inhale_exhale;
+		$res->{default} = $self->exhale;
 	}
 
 	if (defined $self->example) {
-		$res->{example} = $self->inhale_exhale($self->example);
+		$res->{example} = $self->example;
 	}
 
 	return $res;
@@ -34,7 +32,7 @@ sub _inhale
 	my $inhaled = $self->SUPER::_inhale($value);
 	return $inhaled if defined $inhaled;
 	return 'string' if ref $value;
-	return $self->_inhale_extra_rules($value);
+	return undef;
 }
 
 sub _exhale
