@@ -1,11 +1,10 @@
 package Whelk::Schema::Definition::_Scalar;
-$Whelk::Schema::Definition::_Scalar::VERSION = '0.99_01'; # TRIAL
-$Whelk::Schema::Definition::_Scalar::VERSION = '0.9901';
-use Whelk::StrictBase 'Whelk::Schema::Definition';
+$Whelk::Schema::Definition::_Scalar::VERSION = '0.01';
+use Kelp::Base 'Whelk::Schema::Definition';
 
-attr '?required' => sub { !defined $_[0]->default };
-attr '?default' => undef;
-attr '?example' => undef;
+attr required => sub { !defined $_[0]->default };
+attr default => undef;
+attr example => undef;
 
 sub has_default
 {
