@@ -1,6 +1,5 @@
 package Whelk::Wrapper::Simple;
-$Whelk::Wrapper::Simple::VERSION = '0.99_01'; # TRIAL
-$Whelk::Wrapper::Simple::VERSION = '0.9901';
+$Whelk::Wrapper::Simple::VERSION = '0.01';
 use Kelp::Base 'Whelk::Wrapper';
 use Kelp::Exception;
 
@@ -21,7 +20,7 @@ sub wrap_success
 sub build_response_schemas
 {
 	my ($self, $endpoint) = @_;
-	my $schema = $endpoint->response;
+	my $schema = $endpoint->response_schema;
 	my $schemas = $endpoint->response_schemas;
 
 	$schemas->{200} = $schema;
