@@ -1,6 +1,5 @@
 package Whelk::Wrapper::WithStatus;
-$Whelk::Wrapper::WithStatus::VERSION = '0.99_01'; # TRIAL
-$Whelk::Wrapper::WithStatus::VERSION = '0.9901';
+$Whelk::Wrapper::WithStatus::VERSION = '0.01';
 use Kelp::Base 'Whelk::Wrapper';
 
 use Whelk::Schema;
@@ -28,7 +27,7 @@ sub wrap_success
 sub build_response_schemas
 {
 	my ($self, $endpoint) = @_;
-	my $schema = $endpoint->response;
+	my $schema = $endpoint->response_schema;
 	my $schemas = $endpoint->response_schemas;
 
 	if ($schema && $schema->empty) {
